pybedtools.contrib.IntersectionMatrix
=====================================

.. currentmodule:: pybedtools.contrib

.. autoclass:: IntersectionMatrix

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~IntersectionMatrix.__init__
      ~IntersectionMatrix.add_row
      ~IntersectionMatrix.create_matrix
      ~IntersectionMatrix.done
      ~IntersectionMatrix.get_row
      ~IntersectionMatrix.print_matrix
      ~IntersectionMatrix.run_and_insert
   
   

   
   
   